==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/AnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let AnchoredCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class AnchoredCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (AnchoredCategorySeriesDescriptionMetadata.a == null) {
                AnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AnchoredCategorySeriesDescriptionMetadata.c(AnchoredCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(AnchoredCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(AnchoredCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            CategorySeriesDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("HighlightedValueMemberPath", "String");
            a.item("ValueMemberAsLegendLabel", "String");
            a.item("ValueMemberAsLegendUnit", "String");
            a.item("TrendLineType", "ExportedType:string:TrendLineType");
            a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
            a.item("TrendLineBrush", "Brush");
            a.item("ActualTrendLineBrush", "Brush");
            a.item("TrendLineThickness", "Number:double");
            a.item("TrendLineDashArray", "DoubleCollection:double");
            a.item("TrendLinePeriod", "Number:int");
            a.item("MarkerCollisionAvoidance", "ExportedType:string:CategorySeriesMarkerCollisionAvoidance");
            a.item("MarkerCollisionAvoidance@names", "None;Omit");
            a.item("ConsolidatedItemHitTestBehavior", "ExportedType:string:ConsolidatedItemHitTestBehavior");
            a.item("ConsolidatedItemHitTestBehavior@names", "Basic;NearestY");
        }
        static d(a) {
            AnchoredCategorySeriesDescriptionMetadata.b(a);
            a.ac("AnchoredCategorySeries", AnchoredCategorySeriesDescriptionMetadata.a);
        }
    }
    AnchoredCategorySeriesDescriptionMetadata.$t = markType(AnchoredCategorySeriesDescriptionMetadata, 'AnchoredCategorySeriesDescriptionMetadata');
    AnchoredCategorySeriesDescriptionMetadata.a = null;
    return AnchoredCategorySeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/AnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let AnchoredCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class AnchoredCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (AnchoredCategorySeriesDescriptionMetadata.a == null) {
                AnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AnchoredCategorySeriesDescriptionMetadata.c(AnchoredCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(AnchoredCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(AnchoredCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            CategorySeriesDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("HighlightedValueMemberPath", "String");
            a.item("ValueMemberAsLegendLabel", "String");
            a.item("ValueMemberAsLegendUnit", "String");
            a.item("TrendLineType", "ExportedType:string:TrendLineType");
            a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
            a.item("TrendLineBrush", "Brush");
            a.item("ActualTrendLineBrush", "Brush");
            a.item("TrendLineThickness", "Number:double");
            a.item("TrendLineDashArray", "DoubleCollection:double");
            a.item("TrendLinePeriod", "Number:int");
            a.item("MarkerCollisionAvoidance", "ExportedType:string:CategorySeriesMarkerCollisionAvoidance");
            a.item("MarkerCollisionAvoidance@names", "None;Omit");
            a.item("ConsolidatedItemHitTestBehavior", "ExportedType:string:ConsolidatedItemHitTestBehavior");
            a.item("ConsolidatedItemHitTestBehavior@names", "Basic;NearestY");
        }
        static d(a) {
            AnchoredCategorySeriesDescriptionMetadata.b(a);
            a.ad("AnchoredCategorySeries", AnchoredCategorySeriesDescriptionMetadata.a);
        }
    }
    AnchoredCategorySeriesDescriptionMetadata.$t = markType(AnchoredCategorySeriesDescriptionMetadata, 'AnchoredCategorySeriesDescriptionMetadata');
    AnchoredCategorySeriesDescriptionMetadata.a = null;
    return AnchoredCategorySeriesDescriptionMetadata;
})();
